==> django-cascading-dropdown-widget-0.1.0.tar.gz: django-cascading-dropdown-widget-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = fobj.readlines()
requires = [x.strip() for x in requires if x.strip()]

setup(
    name="django-cascading-dropdown-widget",
    version="0.1.0",
    description="Provide a cascading-dropdown widget for django.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="zencore",
    author_email="dobetter@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django cascading dropdown widget"],
    install_requires=requires,
    packages=find_packages(".", exclude=["django_cascading_dropdown_widget_example", "django_cascading_dropdown_widget_example.migrations", "django_cascading_dropdown_widget_demo"]),
    py_modules=["django_cascading_dropdown_widget"],
    zip_safe=False,
    include_package_data=True,
)

==> django-cascading-dropdown-widget-0.2.7.tar.gz: django-cascading-dropdown-widget-0.2.7/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-cascading-dropdown-widget",
    version="0.2.7",
    description="Provide a cascading-dropdown widget for django.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Li Su",
    author_email="lisu@zencore.cn",
    maintainer="Li Su",
    maintainer_email="lisu@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django cascading dropdown widget"],
    install_requires=requires,
    packages=find_packages(
        ".",
        exclude=[
            "django_cascading_dropdown_widget_example",
            "django_cascading_dropdown_widget_example.migrations",
            "django_cascading_dropdown_widget_demo",
        ],
    ),
    py_modules=["django_cascading_dropdown_widget"],
    zip_safe=False,
    include_package_data=True,
)
